@@ -93,7 +93,7 @@ use Log::Fine::Levels;
 use Log::Fine::Logger;
 use POSIX qw( strftime );
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 =head2 Formatters
 
@@ -145,9 +145,7 @@ To install Log::Fine:
                      and not $levelmap) {
                         $levelmap = $map;
                 } elsif (defined $map and not $levelmap) {
-                        _fatal(
-                                sprintf("Invalid Value: \"%s\"",
-                                        $map || "{undef}"));
+                        _fatal(sprintf("Invalid Value: \"%s\"", $map || "{undef}"));
                 }
 
                 return $levelmap;
@@ -397,10 +395,6 @@ sub _fatal
 
         confess $msg;
 
-        #
-        # NOT REACHED
-        #
-
 }          # _fatal()
 
 ##
@@ -520,7 +514,7 @@ L<via email|/AUTHOR>.
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
