@@ -130,10 +130,6 @@ sub format
                 $self->_fatal("call to abstract method ${class}::format()");
         }
 
-        #
-        # NOT REACHED
-        #
-
 }          # format()
 
 =head2 testFormat
@@ -224,8 +220,7 @@ sub _init
         if ($self->{hires}) {
 
                 eval "require Time::HiRes";
-                $self->_fatal(  "Time::HiRes failed to load.  "
-                              . "Please install Time::HiRes via CPAN : $@")
+                $self->_fatal("Time::HiRes failed to load.  " . "Please install Time::HiRes via CPAN : $@")
                     if $@;
 
                 # Set {timestamp_format} to default high precision
@@ -239,8 +234,7 @@ sub _init
                     unless (defined $self->{precision}
                             and $self->{precision} =~ /^\d+$/);
 
-                $self->{_precision_format_str} =
-                    "%.0" . $self->{precision} . "f";
+                $self->{_precision_format_str} = "%.0" . $self->{precision} . "f";
 
         } else {
 
@@ -268,8 +262,7 @@ sub _formatTime
         if ($self->{hires}) {
 
                 # use Time::HiRes to get seconds and milliseconds
-                my $time =
-                    sprintf($self->{_precision_format_str}, &Time::HiRes::time);
+                my $time = sprintf($self->{_precision_format_str}, &Time::HiRes::time);
                 my @t = split /\./, $time;
 
                 # and format
@@ -322,7 +315,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
