@@ -91,10 +91,7 @@ sub format
         my $skip = shift;          # NOT USED
 
         # Return the formatted string
-        return
-            sprintf("[%s] %-4s %s\n",
-                    $self->_formatTime(), $self->levelMap()->valueToLevel($lvl),
-                    $msg);
+        return sprintf("[%s] %-4s %s\n", $self->_formatTime(), $self->levelMap()->valueToLevel($lvl), $msg);
 
 }          # format()
 
@@ -136,7 +133,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
