@@ -95,14 +95,11 @@ sub format
         my $self = shift;
         my $lvl  = shift;
         my $msg  = shift;
-        my $skip =
-            (defined $_[0]) ? shift : Log::Fine::Logger->LOG_SKIP_DEFAULT;
+        my $skip = (defined $_[0]) ? shift : Log::Fine::Logger->LOG_SKIP_DEFAULT;
 
         my $host = (split(/\./, hostname))[0];
 
-        return
-            sprintf("%s %s %s[%d]: %s\n",
-                    $self->_formatTime(), $host, basename($0), $$, $msg);
+        return sprintf("%s %s %s[%d]: %s\n", $self->_formatTime(), $host, basename($0), $$, $msg);
 
 }          # format()
 
@@ -144,7 +141,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
