@@ -165,8 +165,7 @@ sub format
         my $self = shift;
         my $lvl  = shift;
         my $msg  = shift;
-        my $skip =
-            (defined $_[0]) ? shift : Log::Fine::Logger->LOG_SKIP_DEFAULT;
+        my $skip = (defined $_[0]) ? shift : Log::Fine::Logger->LOG_SKIP_DEFAULT;
 
         my $tmpl    = $self->{template};
         my $v2l     = $self->levelMap()->valueToLevel($lvl);
@@ -329,8 +328,7 @@ sub _placeHolders
                 $placeholders->{filename} = sub { return $self->{_fileName} }
                     if ($tmpl =~ /%%FILENAME%%/i);
 
-                $placeholders->{lineno} =
-                    sub { my $skip = shift; return (caller($skip))[2] || 0 }
+                $placeholders->{lineno} = sub { my $skip = shift; return (caller($skip))[2] || 0 }
                     if ($tmpl =~ /%%LINENO%%/i);
 
                 $placeholders->{subrout} = sub {
@@ -339,8 +337,7 @@ sub _placeHolders
                     }
                     if ($tmpl =~ /%%SUBROUT%%/i);
 
-                $placeholders->{hostshort} =
-                    sub { return (split /\./, $self->{_fullHost})[0] }
+                $placeholders->{hostshort} = sub { return (split /\./, $self->{_fullHost})[0] }
                     if ($tmpl =~ /%%HOSTSHORT%%/i);
 
                 $placeholders->{hostlong} = sub { return $self->{_fullHost} }
@@ -355,10 +352,8 @@ sub _placeHolders
                 # Check for custom templates
                 if (defined $self->{custom_placeholders}) {
 
-                        foreach my $placeholder (
-                                       keys %{ $self->{custom_placeholders} }) {
-                                $placeholders->{$placeholder} =
-                                    $self->{custom_placeholders}->{$placeholder}
+                        foreach my $placeholder (keys %{ $self->{custom_placeholders} }) {
+                                $placeholders->{$placeholder} = $self->{custom_placeholders}->{$placeholder}
                                     if ($tmpl =~ /%%${placeholder}%%/i);
                         }
 
@@ -370,10 +365,6 @@ sub _placeHolders
 
         }
 
-        #
-        # NOT REACHED
-        #
-
 }          # _placeHolder()
 
 ##
@@ -391,21 +382,16 @@ sub _placeholderValidate
         foreach my $placeholder (keys %{ $self->{custom_placeholders} }) {
 
                 $self->_fatal(
-                        sprintf("custom template '%s' must point to "
-                                    . "a valid function ref : %s",
-                                $placeholder,
-                                ref $self->{custom_placeholders}->{$placeholder}
-                        ))
-                    unless ref $self->{custom_placeholders}->{$placeholder} eq
-                            "CODE";
+                              sprintf("custom template '%s' must point to " . "a valid function ref : %s",
+                                      $placeholder, ref $self->{custom_placeholders}->{$placeholder})
+                ) unless ref $self->{custom_placeholders}->{$placeholder} eq "CODE";
 
                 # Check for duplicate placeholders
                 if (defined $holders->{ lc($placeholder) }) {
                         $self->_fatal(
-                                sprintf("Duplicate placeholder '%s' found.  "
-                                            . "Remember, placeholders are case-INsensitive",
-                                        $placeholder
-                                ));
+                                      sprintf("Duplicate placeholder '%s' found.  " . "Remember, placeholders are case-INsensitive",
+                                              $placeholder
+                                      ));
                 } else {
                         $holders->{ lc($placeholder) } = 1;
                 }
@@ -444,7 +430,7 @@ sub _userName
 =head1 MICROSOFT WINDOWS CAVEATS
 
 Under Microsoft Windows operating systems (WinXP, Win2003, Vista,
-Win7, etc), Log::Fine::Formatters::Template will use the following
+Win7, etc.), Log::Fine::Formatters::Template will use the following
 environment variables for determining user and group information:
 
 =over
@@ -499,7 +485,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
