@@ -69,8 +69,7 @@ sub bitmaskListEnabled
         # module ;)
         foreach my $maskname ($map->logMasks()) {
                 push @bitmasks, $maskname
-                    if $self->isLoggable(
-                                log($map->maskToValue($maskname)) / log(2) - 1);
+                    if $self->isLoggable(log($map->maskToValue($maskname)) / log(2) - 1);
         }
 
         return @bitmasks;
@@ -205,10 +204,6 @@ sub msgWrite
 
         $self->_fatal($msg);
 
-        #
-        # NOT REACHED
-        #
-
 }          # msgWrite()
 
 # --------------------------------------------------------------------
@@ -277,7 +272,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
