@@ -94,6 +94,25 @@ will take precedence when defining a transport:
 
 See L<Email::Sender::Manual::Quickstart> for further details.
 
+=head2 Email Address Validation
+
+Log::Fine::Handle::Email will validate each email addresses prior to
+use.  Upon initilization, L::F::H::E will search for and use the
+following email address validation modules in the following order of
+preference:
+
+=over
+
+=item  * L<Mail::RFC822::Address>
+
+=item  * L<Email::Valid>
+
+=back
+
+Should neither Mail::RFC822::Address nor Email::Valid be found, then a
+default regex will be used which should work for most instances.  See
+L<CAVEATS> for special considerations.
+
 =head2 Constructor Parameters
 
 The following parameters can be passed to
@@ -164,16 +183,50 @@ use 5.008_003;          # Email::Sender requires Moose which requires 5.8.3
 
 use base qw( Log::Fine::Handle );
 
+use Carp qw(carp);
+
 #use Data::Dumper;
 use Email::Sender::Simple qw(try_to_sendmail);
 use Email::Simple;
-use Mail::RFC822::Address qw(valid validlist);
 use Log::Fine;
 use Log::Fine::Formatter;
 use Sys::Hostname;
 
+BEGIN {
+
+        # Set email address validation routine depending on what
+        # module is installed on this system
+        my @modules = ('Mail::RFC822::Address', 'Email::Valid', 'Default');
+
+        foreach my $module (@modules) {
+
+                if ($module eq 'Default') {
+                        *_isValid = \&_validate_default;
+                        carp 'Using default email validation.  ' . 'Consider Mail::RFC822::Address\n';
+                        last;
+                }
+
+                eval "{ require $module }";
+
+                unless ($@) {
+                        my $sub = '_validate_' . lc($module);
+                        $sub =~ s/\:\:/_/g;
+
+                        *_isValid = \&{$sub};
+                        last;
+                }
+
+                # Reset $@ just in case
+                undef $@;
+
+        }
+
+}
+
 our $VERSION = $Log::Fine::Handle::VERSION;
 
+# --------------------------------------------------------------------
+
 =head1 METHODS
 
 =head2 msgWrite
@@ -196,18 +249,15 @@ sub msgWrite
 
         my $email =
             Email::Simple->create(
-                 header => [
-                        To   => $self->{header_to},
-                        From => $self->{header_from},
-                        Subject =>
-                            $self->{subject_formatter}->format($lvl, "", $skip),
-                 ],
-                 body => $self->{body_formatter}->format($lvl, $msg, $skip),
+                                  header => [ To      => $self->{header_to},
+                                              From    => $self->{header_from},
+                                              Subject => $self->{subject_formatter}->format($lvl, "", $skip),
+                                  ],
+                                  body => $self->{body_formatter}->format($lvl, $msg, $skip),
             );
 
         # Set X-Mailer
-        $email->header_set("X-Mailer",
-                           sprintf("%s ver %s", ref $self, $VERSION));
+        $email->header_set("X-Mailer", sprintf("%s ver %s", ref $self, $VERSION));
 
         $self->_error("Unable to deliver email: $_")
             unless (try_to_sendmail($email, $self->{envelope}));
@@ -235,9 +285,8 @@ sub _init
                 $self->{header_from} =
                     printf("%s@%s", $self->_userName(), $self->_hostName());
         } elsif (defined $self->{header_from}
-                 and not valid($self->{header_from})) {
-                $self->_fatal(
-                         "{header_from} must be a valid RFC 822 Email Address");
+                 and not $self->_isValid($self->{header_from})) {
+                $self->_fatal("{header_from} must be a valid RFC 822 Email Address");
         }
 
         # Validate To address
@@ -249,30 +298,27 @@ sub _init
         # Check for array ref
         if (ref $self->{header_to} eq "ARRAY") {
 
-                if (validlist($self->{header_to})) {
+                if ($self->_isValid($self->{header_to})) {
                         $self->{header_to} = join(",", @{ $self->{header_to} });
                 } else {
-                        $self->_fatal(  "{header_to} must contain valid "
-                                      . "RFC 822 email addresses");
+                        $self->_fatal("{header_to} must contain valid " . "RFC 822 email addresses");
                 }
 
-        } elsif (not valid($self->{header_to})) {
-                $self->_fatal(  "{header_to} must contain a valid "
-                              . "RFC 822 email address");
+        } elsif (not $self->_isValid($self->{header_to})) {
+                $self->_fatal("{header_to} must contain a valid " . "RFC 822 email address");
         }
 
         # Validate subject formatter
-        $self->_fatal(  "{subject_formatter} must be a valid "
-                      . "Log::Fine::Formatter object")
-            unless (   defined $self->{subject_formatter}
-                   and ref $self->{subject_formatter}
-                   and UNIVERSAL::can($self->{subject_formatter}, 'isa')
-                   and $self->{subject_formatter}->isa("Log::Fine::Formatter"));
+        $self->_fatal("{subject_formatter} must be a valid " . "Log::Fine::Formatter object")
+            unless (    defined $self->{subject_formatter}
+                    and ref $self->{subject_formatter}
+                    and UNIVERSAL::can($self->{subject_formatter}, 'isa')
+                    and $self->{subject_formatter}->isa("Log::Fine::Formatter"));
 
         # Validate body formatter
-        $self->_fatal(  "{body_formatter} must be a valid "
-                      . "Log::Fine::Formatter object : "
-                      . ref $self->{body_formatter} || "{undef}")
+        $self->_fatal(
+                "{body_formatter} must be a valid " . "Log::Fine::Formatter object : " . ref $self->{body_formatter}
+                    || "{undef}")
             unless (    defined $self->{body_formatter}
                     and ref $self->{body_formatter}
                     and UNIVERSAL::can($self->{body_formatter}, 'isa')
@@ -284,8 +330,8 @@ sub _init
         # Check Envelope Transport
         if (defined $envelope->{transport}) {
                 my $transtype = ref $envelope->{transport};
-                $self->_fatal(  "{envelope}->{transport} must be a valid "
-                              . "Email::Sender::Transport object : $transtype")
+                $self->_fatal(
+                              "{envelope}->{transport} must be a valid " . "Email::Sender::Transport object : $transtype")
                     unless ($transtype =~ /^Email\:\:Sender\:\:Transport/);
         }
 
@@ -295,28 +341,26 @@ sub _init
                               . "array ref containing one or more valid "
                               . "RFC 822 email addresses")
                     unless (ref $envelope->{to} eq "ARRAY"
-                            and validlist($envelope->{to}));
+                            and $self->_isValid($envelope->{to}));
         }
 
         # Check envelope from
         if (defined $envelope->{from} and $envelope->{from} =~ /\w/) {
-                $self->_fatal(  "{envelope}->{from} must be a "
-                              . "valid RFC 822 Email Address")
-                    unless valid($envelope->{from});
+                $self->_fatal("{envelope}->{from} must be a " . "valid RFC 822 Email Address")
+                    unless $self->_isValid($envelope->{from});
         } else {
                 $envelope->{from} = $self->{header_from};
         }
 
         # Validate subject formatter
-        $self->_fatal(  "{subject_formatter} must be a valid "
-                      . "Log::Fine::Formatter object")
+        $self->_fatal("{subject_formatter} must be a valid " . "Log::Fine::Formatter object")
             unless (defined $self->{subject_formatter}
-                   and $self->{subject_formatter}->isa("Log::Fine::Formatter"));
+                    and $self->{subject_formatter}->isa("Log::Fine::Formatter"));
 
         # Validate body formatter
-        $self->_fatal(  "{body_formatter} must be a valid "
-                      . "Log::Fine::Formatter object : "
-                      . ref $self->{body_formatter} || "{undef}")
+        $self->_fatal(
+                "{body_formatter} must be a valid " . "Log::Fine::Formatter object : " . ref $self->{body_formatter}
+                    || "{undef}")
             unless (defined $self->{body_formatter}
                     and $self->{body_formatter}->isa("Log::Fine::Formatter"));
 
@@ -366,6 +410,109 @@ sub _userName
 
 }          # _userName()
 
+##
+# Default email address checker
+#
+# Parameters:
+#
+#  - addy : either a scalar containing a string to check or an array
+#           ref containing one or more strings to check
+#
+# Returns:
+#
+#  1 on success, undef otherwise
+
+sub _validate_default
+{
+
+        my $self = shift;
+        my $addy = shift;
+
+        if (ref $addy eq "ARRAY") {
+                foreach my $address (@{$addy}) {
+                        return undef
+                            unless $address =~
+/^[a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+\@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/;
+                }
+        } else {
+                return undef
+                    unless ($addy =~
+/^[a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+\@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/
+                    );
+        }
+
+        return 1;
+
+}          # _validate_default()
+
+##
+# Validate email address via Email::Valid
+#
+# Parameters:
+#
+#  - addy : either a scalar containing a string to check or an array
+#           ref containing one or more strings to check
+#
+# Returns:
+#
+#  1 on success, undef otherwise
+
+sub _validate_email_valid
+{
+
+        my $self = shift;
+        my $addy = shift;
+
+        my $validator = Email::Valid->new();
+
+        if (ref $addy eq 'ARRAY') {
+                foreach my $address (@{$addy}) {
+                        return undef unless $validator->address($address);
+                }
+        } else {
+                return undef unless $validator->address($addy);
+        }
+
+        return 1;
+
+}          # _validate_email_valid()
+
+##
+# Validate email address via Mail::RFC822::Address
+#
+# Parameters:
+#
+#  - addy : either a scalar containing a string to check or an array
+#           ref containing one or more strings to check
+#
+# Returns:
+#
+#  1 on success, undef otherwise
+
+sub _validate_mail_rfc822_address
+{
+
+        my $self = shift;
+        my $addy = shift;
+
+        if (ref $addy eq "ARRAY") {
+                return Mail::RFC822::Address::validlist($addy);
+        } else {
+                return Mail::RFC822::Address::valid($addy);
+        }
+
+}          # _validate_mail_rfc822_address()
+
+=head1 CAVEATS
+
+Note that the L<Email::Valid> module does not use the same checking
+algorithms as L<Mail::RFC822::Address>.  Email addresses considered
+valid under one module may not be considered valid under the other.
+For example, under Mail::RFC822::Address, C<jsmith@localhost> is
+considered a valid address while Email::Valid will reject it.
+Consider researching each module prior to making a determination as to
+which is acceptable for your environment and needs.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -404,7 +551,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
