@@ -168,9 +168,7 @@ sub msgWrite
         if ($self->{autoclose}) {
                 $fh->close()
                     || $self->_error(
-                                sprintf("Unable to close filehandle to %s : %s",
-                                        catdir($self->{dir}, $self->{file}), $!
-                                ));
+                                 sprintf("Unable to close filehandle to %s : %s", catdir($self->{dir}, $self->{file}), $!));
         }
 
         return $self;
@@ -271,7 +269,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
