@@ -107,10 +107,7 @@ sub _fileHandle
         # Close existing file handle
         if ($doclose) {
                 $self->{_filehandle}->close()
-                    || $self->_error(
-                               sprintf("Unable to close file handle to %s : %s",
-                                       $filename, $!
-                               ));
+                    || $self->_error(sprintf("Unable to close file handle to %s : %s", $filename, $!));
         }
 
         $self->{_filehandle} = FileHandle->new(">> " . $filename)
@@ -165,7 +162,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
