@@ -185,8 +185,7 @@ sub AUTOLOAD
         croak(
                sprintf("[%s] {%s} FATAL : %s\n",
                        strftime("%c", localtime(time)),
-                       $AUTOLOAD,
-                       "Invalid function name : $name"
+                       $AUTOLOAD, "Invalid function name : $name"
                )) unless (exists $ok_fields{$name});
 
         # Evaluate and return the appropriate level
@@ -233,7 +232,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
