@@ -137,8 +137,7 @@ use constant MASK_MAP => {
                            LOGMASK_WARNING => 2 << LVLTOVAL_MAP->{WARN},
                            LOGMASK_NOTICE  => 2 << LVLTOVAL_MAP->{NOTI},
                            LOGMASK_INFO    => 2 << LVLTOVAL_MAP->{INFO},
-                           LOGMASK_DEBUG   => 2 << LVLTOVAL_MAP->{DEBG}
-};          # MASK_MAP{}
+                           LOGMASK_DEBUG   => 2 << LVLTOVAL_MAP->{DEBG} };          # MASK_MAP{}
 
 # --------------------------------------------------------------------
 
@@ -194,8 +193,7 @@ sub AUTOLOAD
         croak(
                sprintf("[%s] {%s} FATAL : %s\n",
                        strftime("%c", localtime(time)),
-                       $AUTOLOAD,
-                       "Invalid function name : $name"
+                       $AUTOLOAD, "Invalid function name : $name"
                )) unless (exists $ok_fields{$name});
 
         # Evaluate and return the appropriate level
@@ -242,7 +240,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 AUTHOR
 
-Christopher M. Fuhrman, C<< <cfuhrman at panix.com> >>
+Christopher M. Fuhrman, C<< <cfuhrman at pobox.com> >>
 
 =head1 SEE ALSO
 
